@@ -8,7 +8,9 @@ huge-count.pl --tokenlist --newline --split 100 testA1.hugecount testA1.data
 
 count2huge.pl --split 1 testA1.count A2  
 
-diff ./A2/count2huge.output ./testA1.hugecount/huge-count.output > ./A2/var
+if((-e ./A2/count2huge.output) && (-e ./testA1.hugecount/complete-huge-count.output)) then
+diff ./A2/count2huge.output ./testA1.hugecount/complete-huge-count.output > ./A2/var
+endif
 
 if( -z ./A2/var ) then
 	echo "Test Ok";
