@@ -11,11 +11,13 @@ huge-delete.pl --frequency 2 --ufrequency 5 test-1.output test-1.delete1
 echo "Running count.pl --newline --frequency 2  --ufrequency 5 test-1.delete2 test-1.txt" 
 count.pl --newline --frequency 2 --ufrequency 5 test-1.delete2 test-1.txt
 
-
-sort test-1.delete1 > t0
-sort test-1.delete2 > t1
-
-diff t0 t1 > var
+if((-e test-1.delete1) && (-e test-1.delete2)) then
+	sort test-1.delete1 > t0;
+	sort test-1.delete2 > t1;
+	diff t0 t1 > var;
+else
+	echo "Test Error";
+endif
 
 if(-z var) then
 	echo "Test Ok";
