@@ -24,7 +24,7 @@ Text::NSP::Measures::3D::MI::ll - Perl module that implements Loglikelihood
   }
   else
   {
-    print getStatisticName."value for bigram is ".$ll_value."\n";
+    print getStatisticName."value for trigram is ".$ll_value."\n";
   }
 
 
@@ -51,8 +51,6 @@ cell is computed to arrive at the log-likelihood value.
            n211 * log(n211/m211) + n212 * log(n212/m212) +
            n221 * log(n221/m221) + n222 * log(n222/m222)]
 
-=head2 Methods
-
 =over
 
 =cut
@@ -149,14 +147,14 @@ Amruta Purandare,            University of Pittsburgh
                              E<lt>amruta@cs.pitt.eduE<gt>
 
 Bridget Thomson-McInnes,     University of Minnesota Twin Cities
-                             E<lt>bthompson@d.umn.eduE<gt>
+                             E<lt>bthomson@d.umn.eduE<gt>
 
 Saiyam Kohli,                University of Minnesota Duluth
                              E<lt>kohli003@d.umn.eduE<gt>
 
 =head1 HISTORY
 
-Last updated: $Id: ll.pm,v 1.9 2006/06/21 11:10:53 saiyam_kohli Exp $
+Last updated: $Id: ll.pm,v 1.10 2011/12/23 21:59:33 btmcinnes Exp $
 
 =head1 BUGS
 
@@ -194,7 +192,7 @@ L<http://www.d.umn.edu/~tpederse/nsp.html>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2000-2006, Ted Pedersen, Satanjeev Banerjee, Amruta
+Copyright (C) 2000-2011, Ted Pedersen, Satanjeev Banerjee, Amruta
 Purandare, Bridget Thomson-McInnes and Saiyam Kohli
 
 This program is free software; you can redistribute it and/or modify it
@@ -218,4 +216,4 @@ Note: a copy of the GNU General Public License is available on the web
 at L<http://www.gnu.org/licenses/gpl.txt> and is included in this
 distribution as GPL.txt.
 
-=cut
\ No newline at end of file
+=cut
